@@ -16,12 +16,12 @@ from datetime import datetime
 from typing import List
 
 from .literals import (
-    ConnectionType,
-    EnvironmentLifecycleStatus,
-    EnvironmentStatus,
-    EnvironmentType,
-    ManagedCredentialsStatus,
-    Permissions,
+    ConnectionTypeType,
+    EnvironmentLifecycleStatusType,
+    EnvironmentStatusType,
+    EnvironmentTypeType,
+    ManagedCredentialsStatusType,
+    PermissionsType,
 )
 
 if sys.version_info >= (3, 8):
@@ -73,7 +73,7 @@ DescribeEnvironmentMembershipsResultTypeDef = TypedDict(
 DescribeEnvironmentStatusResultTypeDef = TypedDict(
     "DescribeEnvironmentStatusResultTypeDef",
     {
-        "status": EnvironmentStatus,
+        "status": EnvironmentStatusType,
         "message": str,
     },
 )
@@ -89,7 +89,7 @@ DescribeEnvironmentsResultTypeDef = TypedDict(
 EnvironmentLifecycleTypeDef = TypedDict(
     "EnvironmentLifecycleTypeDef",
     {
-        "status": EnvironmentLifecycleStatus,
+        "status": EnvironmentLifecycleStatusType,
         "reason": str,
         "failureResource": str,
     },
@@ -99,7 +99,7 @@ EnvironmentLifecycleTypeDef = TypedDict(
 _RequiredEnvironmentMemberTypeDef = TypedDict(
     "_RequiredEnvironmentMemberTypeDef",
     {
-        "permissions": Permissions,
+        "permissions": PermissionsType,
         "userId": str,
         "userArn": str,
         "environmentId": str,
@@ -123,7 +123,7 @@ class EnvironmentMemberTypeDef(
 _RequiredEnvironmentTypeDef = TypedDict(
     "_RequiredEnvironmentTypeDef",
     {
-        "type": EnvironmentType,
+        "type": EnvironmentTypeType,
         "arn": str,
         "ownerArn": str,
     },
@@ -134,9 +134,9 @@ _OptionalEnvironmentTypeDef = TypedDict(
         "id": str,
         "name": str,
         "description": str,
-        "connectionType": ConnectionType,
+        "connectionType": ConnectionTypeType,
         "lifecycle": "EnvironmentLifecycleTypeDef",
-        "managedCredentialsStatus": ManagedCredentialsStatus,
+        "managedCredentialsStatus": ManagedCredentialsStatusType,
     },
     total=False,
 )
